<?php

namespace Drupal\Tests\yasm\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Provides a class for Yasm functional tests.
 *
 * @group yasm
 */
class YasmUserTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = ['node', 'file', 'user', 'yasm'];

  /**
   * Various users for the tests.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser, $basicUser, $deniedUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    // Create users.
    $this->adminUser = $this->drupalCreateUser([
      'view the administration theme',
      'access administration pages',
      'yasm summary',
      'yasm contents',
      'yasm users',
      'yasm files',
      'yasm entities',
      'yasm my summary',
      'yasm my contents',
    ]);
    $this->basicUser = $this->drupalCreateUser([
      'view the administration theme',
      'access administration pages',
      'yasm my summary',
      'yasm my contents',
    ]);
    $this->deniedUser = $this->drupalCreateUser([
      'view the administration theme',
      'access administration pages',
    ]);
  }

  /**
   * Tests users access.
   */
  public function testsUsersAccess() {
    // Tests admin user access.
    $this->drupalLogin($this->adminUser);

    $this->drupalGet('admin/reports/yasm');
    $this->assertSession()->statusCodeEquals(200);
    $this->drupalGet('admin/reports/yasm/site/contents');
    $this->assertSession()->statusCodeEquals(200);
    $this->drupalGet('admin/reports/yasm/site/users');
    $this->assertSession()->statusCodeEquals(200);
    $this->drupalGet('admin/reports/yasm/site/files');
    $this->assertSession()->statusCodeEquals(200);
    $this->drupalGet('admin/reports/yasm/site/entities');
    $this->assertSession()->statusCodeEquals(200);
    $this->drupalGet('admin/reports/yasm/my');
    $this->assertSession()->statusCodeEquals(200);
    $this->drupalGet('admin/reports/yasm/my/contents');
    $this->assertSession()->statusCodeEquals(200);

    // Tests basic user access.
    $this->drupalLogin($this->basicUser);

    $this->drupalGet('admin/reports/yasm');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/site/contents');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/site/users');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/site/files');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/site/entities');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/my');
    $this->assertSession()->statusCodeEquals(200);
    $this->drupalGet('admin/reports/yasm/my/contents');
    $this->assertSession()->statusCodeEquals(200);

    // Tests user without access.
    $this->drupalLogin($this->deniedUser);

    $this->drupalGet('admin/reports/yasm');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/site/contents');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/site/users');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/site/files');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/site/entities');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/my');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalGet('admin/reports/yasm/my/contents');
    $this->assertSession()->statusCodeEquals(403);
  }

}
